"""widetorah — Python SDK for WideTorah.

Access Torah verses, Talmud daf, Rashi commentary, parashot, Jewish holidays,
and biblical figures from the WideTorah REST API.

Usage::

    from widetorah import WideTorah

    with WideTorah() as client:
        verse = client.get_verse("genesis", 1, 1)
        print(verse)
"""

from widetorah.client import WideTorah

__version__ = "0.1.1"

__all__ = [
    "WideTorah",
    "__version__",
]
